Function ark_serialize::buffer_byte_size
source · [−]Expand description
Converts the number of bits required to represent a number into the number of bytes required to represent it.
Converts the number of bits required to represent a number into the number of bytes required to represent it.