Structs

Flags to be encoded into the serialization.

Enums

Whether to use a compressed version of the serialization algorithm. Specific behavior depends on implementation. If no compressed version exists (e.g. on Fp), mode is ignored.
This is an error that could occur during serialization
Whether to validate the element after deserializing it. Specific behavior depends on implementation. If no validation algorithm exists (e.g. on Fp), mode is ignored.

Traits

Deserializer in little endian format. This trait can be derived if all fields of a struct implement CanonicalDeserialize and the derive feature is enabled.
Deserializer in little endian format allowing flags to be encoded.
Serializer in little endian format. This trait can be derived if all fields of a struct implement CanonicalSerialize and the derive feature is enabled.
The CanonicalSerialize induces a natural way to hash the corresponding value, of which this is the convenience trait.
Serializer in little endian format allowing to encode flags.
Represents metadata to be appended to an object’s serialization. For example, when serializing elliptic curve points, one can use a Flag to represent whether the serialization is the point at infinity, or whether the y coordinate is positive or not. These bits will be appended to the end of the point’s serialization, or included in a new byte, depending on space available.
The Read trait allows for reading bytes from a source.

Functions

Converts the number of bits required to represent a number into the number of bytes required to represent it.